'use strict';

var register = require('ignore-styles').default;
// styles
var _ = require('lodash');
var bodyParser = require('body-parser');
var compression = require('compression');
var express = require('express');
var morgan = require('morgan');
var path = require('path');
var fs = require('fs');
var md5File = require('md5-file');

var mimeTypes = {
  '.jpg': 'image/jpeg',
  '.png': 'image/png'
};
register(undefined, function (mod, filename) {
  var ext = ['.png', '.jpg'].find(function (f) {
    return filename.endsWith(f);
  });
  if (!ext) return;

  if (fs.statSync(filename).size < 10000) {
    var file = fs.readFileSync(filename).toString('base64');
    var mimeType = mimeTypes[ext] || 'image/jpg';
    mod.exports = 'data:' + mimeType + ';base64,' + file;
  } else {
    var hash = md5File.sync(filename).slice(0, 8);
    var bn = path.basename(filename).replace(/(\.\w{3})$/, '.' + hash + '$1');
    mod.exports = '/static/media/' + bn;
  }
});

var serverAppFactory = function serverAppFactory(config) {
  var module = {};

  module.createExpressApp = function () {

    // routes
    var index = require('./routes/index');
    var webServicesApi = require('./routes/api');
    var universalLoader = require('./universal');

    // App setup
    var app = express();

    //COORS config
    app.use(function (req, res, next) {
      var allowedOrigins = ["http://localhost:3000"];
      var origin = req.headers.origin;
      if (allowedOrigins.indexOf(origin) > -1) {
        res.setHeader('Access-Control-Allow-Origin', origin);
      }
      res.header('Access-Control-Allow-Methods', 'GET, OPTIONS');
      res.header('Access-Control-Allow-Headers', 'Content-Type, Authorization');
      res.header('Access-Control-Allow-Credentials', true);
      return next();
    });

    //MIDDLEWARE
    //=============
    // Support Gzip
    app.use(compression());
    // Support post requests with body data (doesn't support multipart, use multer)
    app.use(bodyParser.json());
    app.use(bodyParser.urlencoded({ extended: false }));
    // Setup logger
    app.use(morgan('dev'));
    //=============

    //serve website
    //index is simply a router using the universal loader
    app.use('/', index(config));

    // Serve static assets
    app.use(express.static(config.staticAssetsLocation));

    //serve web services
    app.use('/api', webServicesApi(config));
    if (config.apiExpansion) {
      app.use('/api', config.apiExpansion(config));
    }

    // Always return the main index.html, so react-router render the route in the client
    app.use('/', new universalLoader(config));

    return app;
  };

  return module;
};

module.exports = serverAppFactory;